@@ -13,8 +13,8 @@ from torch.utils.data import Dataset, IterableDataset, DataLoader
 import mlflow
 import pytorch_lightning as pl
 from pytorch_lightning.loggers import WandbLogger
-from .callbacks_base import AttnVisCallbackBase, MLflowCallbackBase, TensorboardCallbackBase
-from ..models.multitask import MultiTaskTxT
+from src.lighting.callbacks_base import AttnVisCallbackBase, MLflowCallbackBase, TensorboardCallbackBase
+from src.models.multitask import MultiTaskTxT, MultiTaskTxE
 from pytorch_lightning import LightningModule
 
 
@@ -367,7 +367,7 @@ class OrderDataset(Dataset):
         elif col == self.ctx_cols[2]:
             return self.ctx_np[:, 2].astype(int).max() + 1
         elif col == self.seq_col:
-            return int(self.seq_np.reshape(-1).max()) + 1
+            return max(int(self.seq_np.reshape(-1).max()), int(self.candidate_np.reshape(-1).max())) + 1
         # elif data_col.dtype == "object":
         #     return int(np.array(data_col.to_list()).max()) + 1
         else:
@@ -389,7 +389,7 @@ class OrderDataset(Dataset):
 class PLMultiTaskTxT(LightningModule):
     def __init__(self, task1_criterion, task2_criterion, optimizer, learning_rate,
                  loss_weights=(100, 1), log_interval=100,
-                 multi_task_txt_kwargs=None):
+                 multi_task_txt_model="MultiTaskTxT", multi_task_txt_kwargs=None):
         super().__init__()
         self.task1_criterion = task1_criterion
         self.task2_criterion = task2_criterion
@@ -397,7 +397,12 @@ class PLMultiTaskTxT(LightningModule):
         self.log_interval = log_interval
         self.optimizer = optimizer
         self.learning_rate = learning_rate
-        self.multi_task = MultiTaskTxT(**multi_task_txt_kwargs)
+        if multi_task_txt_model == "MultiTaskTxT":
+            self.multi_task = MultiTaskTxT(**multi_task_txt_kwargs)
+        elif multi_task_txt_model == "MultiTaskTxE":
+            self.multi_task = MultiTaskTxE(**multi_task_txt_kwargs)
+        else:
+            raise NotImplementedError()
         self.epoch_time = time.time()
 
     def forward(self, ctx_in, seq_in, vl_in, candidate_in, seq_history=None):
